function  [X,Xext] = assignVar(LogFile,sub)
%ASSIGN_VAR    assigns measured data to scalar variables.
%
%   [X,Xext] = assign_var(LogFile,sub)
%   
%  X        cell array of extracted variables {x1,x2,...}
%  Xext     string with extract command to be evaluated
%           (e.g., '[x1 x2 ...] = deal(X{:})')
%  LogFile  string with name of log file (e.g. 'logfile')
%  sub      string with subscript to attach each variable
%           (e.g., '_m')            
%
% Version: (author: G-O K)
%  2.2 (Ch Br)  - 27/09/2005, find variableInMatFile added.
%  2.1 (G-O K)  - 12/11/2004, fixed bug with subscript.
%  2.0 (G-O K)  - 13/07/2004, modified to function.
%  1.0 (G-O K)  - 14/05/2003, created. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% NOTES:
% * The function requires that variable names are distinct!


%% %%% LOADING STRUCT WITH MEASUREMENTS %%%
matVariable = findVariableInMatFile(LogFile);
eval(['load ' LogFile '.mat'])      % loads log file

%%% ASSIGNS MEASURED VARIABLES %%%
% Extracts the individual variables:
matVariable
eval(['LOG=' matVariable ';']); % Struct name

N=length(LOG.Y);        % Number of logged signals
Xext='[ ';              % Beginning of extract command string            
for i=1:N
    Name=LOG.Y(i).Name;
    Data=LOG.Y(i).Data;
    % Removes path and '"' from variable name:
    I=findstr('"',Name);
    NewName=[Name(I(end-1)+1:I(end)-1),sub];
    % Replaces variable names 'z{SubArray'#}' with 'z#':
    NewName=strrep(NewName,'{SubArray','');
    NewName=strrep(NewName,'}','');
    % Replaces occurences of '<' and '>' with '' and 'i':
    NewName=strrep(NewName,'<','');
    NewName=strrep(NewName,'>','');
    % Assigns data to variable with new name:
    X{i}=Data;
    Xext=[Xext NewName ' '];
end
% Extracts time vector and sample time:
%eval(sprintf('t%s = %s.X.Data',sub,LOG));
eval(['t' sub '=' matVariable '.X.Data;'])
eval(['dT=' matVariable '.Capture.SamplingPeriod;'])
eval(['X{N+1}=' 't' sub ';'])
X{N+2}=dT;

% Completes the extract command string:
Xext=[Xext 't' sub ' dT ]=deal(X{:});']; 
