%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run simulation model
%
% Erlend Helgeland 28.01.08
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('--------- Start of simmod.m ---------\n');

%Switches
reg_en = 1;%Toggle controller action, 0:measurements 1:controller
init_en = 1;%Toggle running of init-files
filter_switch = 1;%Toggle filter use. 0:simulation states 1:lp filter 2:robust filter
controller_switch =2;% 0:PD controller 1:ideal sliding mode 
%2:Modified boundary layer 3:boundary layer sliding mode 4:2-sliding mode
small_plot = 1;%Toggle minimal plot, for controllers

int = 2801:1:4399;%1:1e4+1;2801:1:4399;%1:1e4+1;%Time interval for plotting

if(init_en)
    simulation_init;%Load initial values
    [X,Y]= assignVar('perftest','_data');%Import measurement data for comparison
    %[X,Y]= assignVar('dc0p1_take2','_data');%Import measurement data for
    %comparison
    %[X,Y]= assignVar('pedal1','_data');%Import measurement data for comparison
    eval(Y);
    filter_init
end
control_init;%Load controller parameters

close all
options = simset('Solver','ode1','FixedStep',0.001);%Simulation solver options
sim('simul',10,options);%Run simulation

%%%%%%%%%%%%%%%%%% Plot results %%%%%%%%%%%%%%%%%%
scrsz = get(0,'ScreenSize');%get screensize
[y,v,a]=splin2(y_m_data,0.001,20);%Spline estimate (for comparasion)

if(small_plot)
    figure('Position',[100 100 scrsz(3)/2+100 1.5*scrsz(4)/2])%subplot(31n)-mal 
    subplot(311)
    plot(time(int),simulation_results(int,1),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_reftraj(int,1),'k:');
    legend('Simulation model','Reference trajectory');
    title('Position simulation result');
    xlabel('Time [s]')
    ylabel('Position [m]')
    
    subplot(312)
    plot(time(int),simulation_results(int,2),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_reftraj(int,2),'k:');
    title('Velocity simulation result')
    legend('Simulation result','Reference trajectory');
    xlabel('Time [s]')
    ylabel('Velocity [m/s]')
    
    subplot(313)
    hold on
    stairs(time(int), simulation_control(int,1),'-','Color',[0.6 0.6 0.6]);
    stairs(time(int),simulation_control(int,2),'k:');
    axis([int(1)*0.001 int(length(int))*0.001+0.001 -0.02 1.02]);
    title('Control effort')
    legend('U_{vs}', 'U_{ve}');
    xlabel('Time [s]')
    ylabel('Duty cycle[]')

else
figure('Position',[100 100 scrsz(3)/2+100 1.5*scrsz(4)/2])%subplot(31n)-mal 
subplot(311)
if(reg_en)
    plot(time(int),simulation_results(int,1),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_reftraj(int,1),'k:');
    legend('Simulation model','Reference trajectory');
    title('Position simulation result');
else
    plot(time(int), y_m_data(int),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_results(int,1),'k');
    title('Position measurement and simulation result')
    legend('Position measurement', 'Simulation model');
    axis([0 10 -0.001 0.025]);
end
xlabel('Time [s]')
ylabel('Position [m]')

subplot(312)
if(reg_en)
    plot(time(int),simulation_results(int,2),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_reftraj(int,2),'k:');
    title('Velocity simulation result')
    legend('Simulation result','Reference trajectory');
else
    plot(time(int), v(int),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_results(int,2),'k');
    title('Velocity and spline estimate of measurement');
    legend('Spline estimate','Simulation model');
        axis([0 10 -0.3 0.3]);
end
xlabel('Time [s]')
ylabel('Velocity [m/s]')

subplot(313)
if(reg_en)
    plot(time(int),simulation_results(int,3),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_reftraj(int,3),'k:');
    title('Acceleration simulation result');
    legend('Simulation result','Reference trajectory');
else
    plot(time(int), a(int),'-','Color',[0.6 0.6 0.6]);
    hold on
    plot(time(int),simulation_results(int,3),'k');
    title('Acceleration and spline estimate of measurement');
    legend('Spline estimate','Simulation model');
        axis([0 10 -15 20]);
end
xlabel('Time [s]')
ylabel('Acceleration [m/s^2]')
%{
plot(time(int),simulation_results(int,3));
title('q_A')
legend('Simulation result')
xlabel('Time [s]')
ylabel('q_A [JKkg^2]')
grid
%}
%{
figure('Position',[100 100 scrsz(3)/2+100 scrsz(4)/4])%subplot(31n)-mal
    hold on
    plot(time(int),p_m_data(int),'-','Color',[0.6 0.6 0.6]);
    plot(time(int),simulation_results(int,4),'k');
    plot(time(int),hat_p(int),':k');
    title('Chamber pressure')
    legend('Measurement','Simulation result','Inverse valve model estimate')
    xlabel('Time [s]')
    ylabel('Pressure [Pa]');
%}  
figure('Position',[100 100 scrsz(3)/2+100 1.5*scrsz(4)/2])%subplot(31n)-mal
subplot(311)
hold on
if reg_en
    stairs(time(int), simulation_control(int,1),'-','Color',[0.6 0.6 0.6]);
    stairs(time(int),simulation_control(int,2),'k:');
    axis([int(1)*0.001 int(length(int))*0.001+0.001 -0.02 1.02]);
    title('Control effort')
    legend('U_{vs}', 'U_{ve}');
    xlabel('Time [s]')
    ylabel('Duty cycle[]')

    subplot(312)
    hold on
    plot(time(int),hat_p(int),'-','Color',[0.6 0.6 0.6]);
    plot(time(int),simulation_results(int,4),'k');
    title('Chamber pressure')
    legend('Pressure estimate','Simulation result p')
    xlabel('Time [s]')
    ylabel('Pressure [Pa]')
    grid

    subplot(313)
    hold on
  %  plot(time(int),simulation_results(int,10),'-','Color',[0.6 0.6 0.6]);
 %   plot(time(int),simulation_results(int,11),'-','Color',[0.4 0.4 0.4]);
    stairs(time(int),simulation_w_d(int),'-','Color',[0.6 0.6 0.6]);
    stairs(time(int), simulation_results(int,10)-simulation_results(int,11),'k');
    title('Actuator chamber flow')
    legend('Desired flow w_d','Flow')
%    legend('w_{in,A}','w_{out,A}');%,'Net flow');
    xlabel('Time [s]')
    ylabel('Mass flow [kg/s]')
else
    subplot(311)
    hold on
    plot(time(int),p_m_data(int),'-','Color',[0.6 0.6 0.6]);
    plot(time(int),simulation_results(int,4),'k');
    %plot(time(int),hat_p(int),':k');
    title('Chamber A pressure')
    legend('Measurement','Simulation result p_A','Inverse valve model estimate')
    xlabel('Time [s]')
    ylabel('Pressure [Pa]');
    
    subplot(312)
    plot(time(int),simulation_results(int,6)-273.15,'k');
    title('Chamber A temperature')
    legend('Simulation result')
    xlabel('Time [s]')
    ylabel('Temperature [C]')
    grid
    
    subplot(313)
    hold on
    %plot(time(int),simulation_results(int,10),'-','Color',[0.6 0.6 0.6]);
    %plot(time(int),simulation_results(int,11),'k');%,'-','Color',[0.4 0.4
    %0.4]);
    plot(time(int), simulation_results(int,10)-simulation_results(int,11),'k-');
    title('Chamber A flow')
    %legend('w_{in,A}','w_{out,A}');%,'Net flow');
    xlabel('Time [s]')
    ylabel('Mass flow [kg/s]')
end

figure('Position',[100 100 scrsz(3)/2+100 1.5*scrsz(4)/2])%subplot(31n)-mal
if reg_en
    subplot(311)
    hold on
    plot(time(int),tracking_error(int,1),'k');
    title('Position tracking error');
    xlabel('Time [s]');
    ylabel('Position error [m]');
    grid
    
    subplot(312)
    hold on
    plot(time(int),tracking_error(int,2),'k');
    title('Velocity tracking error');
    xlabel('Time [s]');
    ylabel('Velocity error [m/s]');
    grid
    
    subplot(313)
    hold on
    plot(time(int),tracking_error(int,3),'k');
    title('Acceleration tracking error');
    xlabel('Time [s]');
    ylabel('Acceleration error [m/s^2]');
    grid
    
else
    subplot(311)
    plot(time(int),simulation_results(int,5),'k');
    grid
    title('Chamber B pressure')
    legend('Simulation result p_B');
    xlabel('Time [s]')
    ylabel('Pressure [Pa]');
    
    subplot(312)
    plot(time(int),simulation_results(int,7)-273.15,'k');
    title('Chamber B temperature');
    xlabel('Time [s]');
    ylabel('Temperature [C]');
    grid
    
    subplot(313)
    %plot(time(int),simulation_results(int,12),time(int),simulation_results(int,13),time(int),simulation_results(int,12)-simulation_results(int,13));
    plot(time(int),simulation_results(int,12)-simulation_results(int,13),'k');
    title('Chamber B flow')
    %legend('w_{in,B}','w_{out,B}','Net flow')
    xlabel('Time [s]')
    ylabel('Mass flow [kg/s]')
    grid
    
    figure('Position',[100 scrsz(4)/2-100 scrsz(3)/2+100 scrsz(4)/4])%plot(11n)-mal
    hold on
    stairs(time(int), simulation_control(int,1),'-','Color',[0.6 0.6 0.6]);
    stairs(time(int),simulation_control(int,2),'k:');
    axis([0 10 -0.02 1.02]);
    title('Control effort')
    legend('U_{vs}', 'U_{ve}');
    xlabel('Time [s]')
    ylabel('Duty cycle[]')
end
% % % % % %
%{
subplot(312)
plot(time(int),simulation_results(int,8));
title('q_B')
legend('Simulation result')
xlabel('Time [s]')
ylabel('q_B [JKkg^2]')
grid
%}
if (reg_en && controller_switch)
    figure('Position',[100 scrsz(4)/2-100 scrsz(3)/2+100 scrsz(4)/4])%plot(11n)-mal
    if(controller_switch==2)
        hold on
        plot(time(int),bl_width(int),'-','Color',[0.6 0.6 0.6]);
        plot(time(int),-bl_width(int),'-','Color',[0.6 0.6 0.6]);
        %axis([int(1)*0.001 int(length(int))*0.001 -150 150]);
    end
    
    plot(time(int),simulation_sigma(int),'k');
    
    if(controller_switch==2)
        legend('Sliding surface','Boundary layer');
    end
    title('Sliding surface \sigma');
    xlabel('Time [s]');
end
figure
hold on
plot(simulation_results(:,1),simulation_results(:,4),'k');
plot(y_m_data,p_m_data,'-','Color',[0.6 0.6 0.6]);
grid
title('p_A vs y');
legend('Simulation results','Measurements');
ylabel('Chamber A pressure p_A [Pa]');
xlabel('Position [m]');

end%end small plot else clause

%Error data
rms_error = norm(tracking_error(:,1))/sqrt(length(tracking_error(:,1)))
max_error = max(abs(tracking_error(:,1)))

fprintf('--------- End of simmod.m ---------\n');