%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Init file for simulation model
%
% Erlend Helgeland 28.01.08
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('--------- Start of simulation_init.m ---------\n');

%%%%%%%%%%%%%%%%%% Simulation model parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Robustness test parameters
y_dev =0;%-0.005;%Starting point deviation
f_l_gain =1;% 1.1;%1.1;%1.07;%Spring force gain
leakflowgain =0;%1e-4*1e-5;%Leak flow from chamber A to chamber B proportional to pressure difference
D_v = 5000%5000;%Viscous friction
noise_enable = 1;%Enable measurement noise
noise_gain = 1;
P_S = 9e5;%[Pa] Supply pressure (Gjone: 9.5e5 Pa)

%Air parameters
T_0 = 293;%[K] Initial/environmental temperature
T_inA = T_0;%[K] Temperature of inlet air to chamber A
T_A0 = T_0;%[K] Initial temperature chamber A
T_inB = T_0;%[K] Temperature of inlet air to chamber B
T_B0 = T_0;%[K] Initial temperature chamber B
P_0 = 1e5;%[Pa] Environmental pressure
P_E = P_0;%[Pa] Exhaust pressure
%P_S = 9e5;%[Pa] Supply pressure (Gjone: 9.5e5 Pa)
R = 287.05;%[J/(kgK)] Dry air gas constant (Gjone: 288 J/KgK)
rho_0 = 1.185;%[kg/m^3] Air density

%Actuator parameters
r_act = (0.125/2);%[m] Actuator piston radius
A_A = pi*r_act^2;%[m^2] Actuator piston area, side A
A_0 = pi*(0.012/2)^2;% Area of the moving part of the actuator exposed to environmental pressure(piston bar area)
A_B = A_A-A_0;%[m^2] Actuator piston area, side B
M = 10;%[kg] Equivalent mass actuator

%Integrator, initial values
y_0 = y_dev;%(7.544e-5)+y_dev;%[m] Initial clutch actuator position
v_0 = 0;%[m/s] 
V_A0 = (1.48e-4)+A_A*y_dev;%[m^3] (KA), initial volume chamber A (Gjone: 0.8e-3 m^3)
V_B0 = (0.57e-3)-A_B*y_dev;%[m^3] (Gjone), initial volume chamber B NB! Ny?

%Flow parameters (Gjone)
B_0 = 0.528;%[] Critical pressure ratio
C_r = 2.1173e-8;%[m^3/(Pas)] Flow conductance of the exhaust restriction
B_r = -0.7596;%[] Parameter in the flow rate model of chamber B NB! Ny?

%Valve parameters (KA)
C_vs = 21.7e-9;%[m^3/Pa s] Supply valve flow conductance
C_ve = 30e-9;%[m^3/Pa s] Exhaust valve flow conductance
T_pwm = 0.01;%[s] Pulse period PWM
%B_vs = 0.6;%[] (Gjone), critical pressure ratio supply valve NB! Ny?
%B_ve = -0.8;%[] (Gjone), critical pressure ratio exhaust valve NB! Ny?

%Fricition parameters (Gjone, Vallevik)
alpha_l = 3.07e3;%[n_root(m^2N^(n-1)] Lip seal friction parameter
D_v = 5e3;%1.39e3;%[Ns/m] Viscous damping coefficient (KA: 2000-5000, dependent on lubrication level)
K_f = 3.26e4;%[N/m] Deflection stiffness
D_f = 1.14e2;%[Ns/m] Deflection damping coefficient
F_C = 1.72e2;%[N] Coulomb friction level
F_S = 3.52e2;%[N] Stiction force level
v_s = 0.2254;%[m/s] Striebeck velocity
n = 0.2899;%[] (Vallevik), Tunable parameter for pre-sliding displacement
y_f_0 = 0;%[m?] Initial pre-sliding displacement/Initial average asperities deflection
y_f_ba = 1e-6;%[m](Lkken 1e-6) (Vallevik), break-away pre-sliding deflection
y_f_max = 1e4;%[m](Lkken 1e-4) (Vallevik), maximum pre-sliding deflection

%Hardstop force parameters
epsilon_h = 5e-4;%(t&e)[m] Smooth indicator and dead zone function smoothing width
y_ub = 0.03;%[m] Smooth indicator and dead zone function upper break point
y_lb = (-epsilon_h/2)+y_dev;%(t&e)[m] Smooth indicator and dead zone function lower break point
K_h = 3e7;%(t&e)1e8;%[N/m] Hardstop spring stiffness
D_h = 1e3;%(t&e)1e3;%[Ns/m] Hardstop damping coefficient

%Temperature and air dynamics parameters (Gjone)
L_w = 2*pi*r_act;%[m] Actuator piston perimeter
kappa = 1.4;%[] Ratio of specific heats
A_wA0 = 0.0141;%0.0293;%4.73e-3;%0.078;%[m^2] Effective area of heat transfer at y=0 (=A_A+(pi*2*r_act*L_(volumV_A0))
A_wB0 = 0.0239;%1e-4;%[m^2] Effective area of heat transfer at y=0 
H_w = 10.16;%[W/(m^2K)] Empirical convective heat coefficient
T_w = T_0;%[K] Cylinder wall temperature

%Sign function approximation
k_signum = 100;%Sign function steepness

%Division by zero avoidance, inverted flow model
G_min=1e-4;%(Gjone)

%Measurement noise
noise_variance = 8.4542e-9;%White noise variance
%noise_enable = 0;%Enable measurement noise

%test_spring_est;%Load clutch spring estimation model data
hege_spring_est;%Create clutch load function

%Hege/Glenn-Ole Kaasa
F_C = 200;%Coloumb friction
D_zDot = 5000;%Deflection damping
K_z = 1e6;%Deflection stiffness
%D_v = 5000;%Viscous friction
epsilon_z = 1e-4;%Tunable smooth absolute value function
z_0=0;%Initial deflection

fprintf('--------- End of simulation_init.m ---------\n');